<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../src/batchprocessing.cpp" line="54"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="55"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Nykyinen kerneli ei tue valittua pakkausalgoritmia, muokkaa asetustiedostoa ja valitse eri algoritmi.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="80"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>Ohjelma pysäyttää koontiversion ja avaa käynnistysvalikon tekstieditorissa.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="162"/>
        <source>No diff output available.</source>
        <translation>Diff-tulostetta ei ole saatavilla.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="200"/>
        <source>Default exclusion file not found at %1.</source>
        <translation>Rajaustiedostoa %1 ei löytynyt.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="210"/>
        <source>Could not remove existing exclusion file at %1.</source>
        <translation>Rajaustiedostoa %1 ei voitu poistaa.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="216"/>
        <source>Could not copy default exclusion file from %1 to %2.</source>
        <translation>Rajaustiedoston kopiointi %1 kansioon %2 ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="232"/>
        <source>Detected newer exclusion file at %1 compared to %2. Prompting for action.</source>
        <translation>Toimintakehotus! Havaittiin uudempi rajaustiedosto %1 verrattuna %2.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="238"/>
        <source>s</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'show diff'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="239"/>
        <source>u</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'use updated default'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="240"/>
        <source>k</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'keep custom (update timestamp)'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="241"/>
        <source>q</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'quit'</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="243"/>
        <source>show diff</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>näytä erot</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="244"/>
        <source>use updated default</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>käytä päivitettyä oletusta</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="245"/>
        <source>keep custom (update timestamp)</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>säilytä mukautettu (päivitä aikaleima)</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="246"/>
        <source>quit</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>lopeta</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="249"/>
        <source>[%1]%2  [%3]%4  [%5]%6  [%7]%8: </source>
        <translation>[%1]%2  [%3]%4  [%5]%6  [%7]%8: </translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="254"/>
        <source>The exclusion file at %1 is newer than your configured file at %2.</source>
        <translation>Rajaustiedosto %1 on uudempi kuin määritetty tiedosto %2.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="270"/>
        <source>Reverted to updated default exclusion file.</source>
        <translation>Palautettu päivitettyyn oletus rajaustiedostoon.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="291"/>
        <source>Leaving custom exclusion file unchanged.</source>
        <translation>Mukautettu rajaustiedosto jätetään ennalleen.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="302"/>
        <source>Invalid choice. Please select again.</source>
        <translation>Valintavirhe. Valitse uudelleen.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="309"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Tietokone käyttää Nvidia näytönohjainta. Käytätkö tuloksena olevaa ISO:a tässä tietokoneessa vai toisessa tietokoneessa, jossa on Nvidia?</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="319"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Huomaa: Jos käytät tuloksena olevaa ISO:a tietokoneessa, jossa ei ole nvidiaa, joudut todennäköisesti poistamaan &quot;xorg=nvidia&quot; käynnistysasetuksista.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="322"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Huomaa: Jos käytät tuloksena olevaa ISO:a tietokoneessa, jossa on nvidia, saatat joutua lisäämään &quot;xorg=nvidia&quot; käynnistysasetuksiin.</translation>
    </message>
</context>
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="82"/>
        <source>No elevation tool found (pkexec/gksu/sudo).</source>
        <translation>Hallintatyökalua ei löytynyt (pkexec/gksu/sudo).</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="116"/>
        <source>Administrator Access Required</source>
        <translation>Pääkäyttäjän oikeudet vaaditaan</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="117"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Toiminto vaatii pääkäyttäjän oikeudet. Käynnistä sovellus uudelleen ja anna salasanasi pyydettäessä.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="439"/>
        <location filename="../src/mainwindow.cpp" line="825"/>
        <location filename="../src/ui_mainwindow.h" line="745"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <location filename="../src/ui_mainwindow.h" line="746"/>
        <source>Optional customization</source>
        <translation>Valinnainen mukautus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <location filename="../src/ui_mainwindow.h" line="747"/>
        <source>Release version:</source>
        <translation>Julkaisuversio:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <location filename="../src/ui_mainwindow.h" line="748"/>
        <source>Boot options:</source>
        <translation>Käynnistysvalinnat:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <location filename="../src/ui_mainwindow.h" line="749"/>
        <source>Live kernel:</source>
        <translation>Live kernel:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <location filename="../src/ui_mainwindow.h" line="750"/>
        <source>Project name:</source>
        <translation>Projektin nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="100"/>
        <location filename="../src/ui_mainwindow.h" line="751"/>
        <source>Release date:</source>
        <translation>Julkaisupäivä:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="107"/>
        <location filename="../src/ui_mainwindow.h" line="752"/>
        <source>Release codename:</source>
        <translation>Julkaisun nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="133"/>
        <location filename="../src/ui_mainwindow.h" line="753"/>
        <source>Current date</source>
        <translation>Nykyinen päivämäärä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <location filename="../src/ui_mainwindow.h" line="754"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot luo nykyisestä järjestelmästä käynnistyvän (ISO) levykuvan. Sen voi asentaa toiseen tietokoneeseen tai jakaa muiden käyttöön. Levykuvan luomisen aikana voit käyttää tietokonetta normaalisti.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="182"/>
        <location filename="../src/ui_mainwindow.h" line="755"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Käytetty kiintolevytila / (root) ja /home:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="192"/>
        <location filename="../src/ui_mainwindow.h" line="756"/>
        <source>Location and ISO name</source>
        <translation>Paikka ja nimi ISO-tiedostolle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="758"/>
        <source>Snapshot location:</source>
        <translation>Vedoksen sijainti:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="226"/>
        <location filename="../src/ui_mainwindow.h" line="759"/>
        <source>Select a different snapshot directory</source>
        <translation>Valitse toinen kansio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="236"/>
        <location filename="../src/mainwindow.cpp" line="634"/>
        <location filename="../src/ui_mainwindow.h" line="760"/>
        <source>Snapshot name:</source>
        <translation>Vedoksen nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="360"/>
        <location filename="../src/ui_mainwindow.h" line="764"/>
        <source>Type of snapshot:</source>
        <translation>Vedoksen tyyppi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="367"/>
        <location filename="../src/ui_mainwindow.h" line="765"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Säilytä käyttäjätilit (oma varmuuskopio)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="377"/>
        <location filename="../src/ui_mainwindow.h" line="767"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Tämä valinta nollaa &amp;quot;demo&amp;quot; ja &amp;quot;root&amp;quot; salasanat MX:n vakiollisiin eikä kopioi mitään henkilökohtaisia luotuja tilejä.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="380"/>
        <location filename="../src/ui_mainwindow.h" line="769"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Poista käyttäjätilit (jaettavaksi muille)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="451"/>
        <location filename="../src/ui_mainwindow.h" line="770"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>Voit rajata pois ruksaamalla alla olevia valintoja tai  muokkaamalla suoraan tiedostoa  /etc/mx-snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="496"/>
        <location filename="../src/ui_mainwindow.h" line="771"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="519"/>
        <location filename="../src/ui_mainwindow.h" line="773"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation>Ohjaa I/O-nopeutta annetulla prosentilla.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="525"/>
        <location filename="../src/ui_mainwindow.h" line="775"/>
        <source>I/O throttle:</source>
        <translation>I/O-kuristin:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="532"/>
        <location filename="../src/ui_mainwindow.h" line="776"/>
        <source>Calculate checksums:</source>
        <translation>Laske tarkistussumma:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="539"/>
        <location filename="../src/ui_mainwindow.h" line="777"/>
        <source>ISO compression scheme:</source>
        <translation>ISO-pakkausmenetelmä:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="546"/>
        <location filename="../src/ui_mainwindow.h" line="778"/>
        <source>Number of CPU cores to use:</source>
        <translation>Käytettävä prosessoriytimien määrä:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="553"/>
        <location filename="../src/ui_mainwindow.h" line="779"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="780"/>
        <source>Options:</source>
        <translation>Asetukset:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="610"/>
        <location filename="../src/ui_mainwindow.h" line="781"/>
        <source>Edit Exclusion File</source>
        <translation>Muokkaa rajaustiedostoa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="626"/>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <location filename="../src/ui_mainwindow.h" line="782"/>
        <source>Remove Custom Exclusion File</source>
        <translation>Poista mukautettu rajaustiedosto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="679"/>
        <location filename="../src/ui_mainwindow.h" line="783"/>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="686"/>
        <location filename="../src/ui_mainwindow.h" line="784"/>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="693"/>
        <location filename="../src/ui_mainwindow.h" line="785"/>
        <source>All of the above</source>
        <translation>Kaikki yläpuolella olevat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="700"/>
        <location filename="../src/ui_mainwindow.h" line="787"/>
        <source>exclude network configurations</source>
        <translation>jätä verkkomääritykset pois</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="703"/>
        <location filename="../src/ui_mainwindow.h" line="789"/>
        <source>Networks</source>
        <translation>Verkot</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="710"/>
        <location filename="../src/ui_mainwindow.h" line="790"/>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="717"/>
        <location filename="../src/ui_mainwindow.h" line="791"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="724"/>
        <location filename="../src/ui_mainwindow.h" line="792"/>
        <source>Documents</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="731"/>
        <location filename="../src/ui_mainwindow.h" line="793"/>
        <source>Flatpaks</source>
        <translation>Flatpakit</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="738"/>
        <location filename="../src/ui_mainwindow.h" line="794"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="850"/>
        <location filename="../src/ui_mainwindow.h" line="797"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="853"/>
        <location filename="../src/ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="859"/>
        <location filename="../src/ui_mainwindow.h" line="801"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="875"/>
        <location filename="../src/ui_mainwindow.h" line="803"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="900"/>
        <location filename="../src/ui_mainwindow.h" line="808"/>
        <source>Display help </source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="903"/>
        <location filename="../src/ui_mainwindow.h" line="810"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="909"/>
        <location filename="../src/ui_mainwindow.h" line="812"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="922"/>
        <location filename="../src/ui_mainwindow.h" line="815"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="925"/>
        <location filename="../src/ui_mainwindow.h" line="817"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="931"/>
        <location filename="../src/ui_mainwindow.h" line="819"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="985"/>
        <location filename="../src/ui_mainwindow.h" line="822"/>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="401"/>
        <source>Select Release Date</source>
        <translation>Valitse julkaisupäivä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="445"/>
        <source>fastest, worst compression</source>
        <translation>nopein, huonoin pakkaus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="445"/>
        <source>fast, worse compression</source>
        <translation>nopea, huonompi pakkaus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <source>slow, better compression</source>
        <translation>hidas, parempi pakkaus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <source>best compromise</source>
        <translation>paras kompromissi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <source>slowest, best compression</source>
        <translation>hitain, paras pakkaus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="476"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Snapshot.kansio tallennetaan vapaaseen tilaan %1: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation>Vapaan tilan pitäisi riittää pakatulle datalle kohteessa / ja /home 

Tarvittaessa tee vapaata tilaa poistamalla aiemmat vedokset ja
tallennetut kopiot: Vedokset %1 vievät %2 levytilaa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="491"/>
        <location filename="../src/mainwindow.cpp" line="492"/>
        <source>Installing </source>
        <translation>Asennetaan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Please wait.</source>
        <translation>Odota, ole hyvä.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="579"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Odota, ole hyvä. Lasketaan käytettyä levytilaa...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="313"/>
        <location filename="../src/mainwindow.cpp" line="324"/>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="613"/>
        <location filename="../src/mainwindow.cpp" line="620"/>
        <location filename="../src/mainwindow.cpp" line="701"/>
        <location filename="../src/mainwindow.cpp" line="720"/>
        <location filename="../src/mainwindow.cpp" line="959"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="177"/>
        <source>No diff output available.</source>
        <translation>Diff-tulostetta ei ole saatavilla.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <location filename="../src/mainwindow.cpp" line="246"/>
        <source>Updated Exclusion List</source>
        <translation>Päivitetty rajauslista</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="213"/>
        <source>The exclusion file at %1 is newer than your configured file at %2.</source>
        <translation>Rajaustiedosto %1 on uudempi kuin määritetty tiedosto %2.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="215"/>
        <source>Review the changes below. Keep your custom file or replace it with the updated default.</source>
        <translation>Tarkista muutokset. Säilytä mukautettu tiedosto tai korvaa se päivitetyllä oletuksella.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="221"/>
        <source>Show Differences</source>
        <translation>Näytä ero</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="227"/>
        <source>Keep Custom</source>
        <translation>Pidä mukautettu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="233"/>
        <source>Use Updated Default</source>
        <translation>Käytä päivitettyä oletusta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="314"/>
        <source>Default exclusion file not found at %1.</source>
        <translation>Rajaustiedostoa %1 ei löytynyt.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="325"/>
        <source>Could not remove existing exclusion file at %1.</source>
        <translation>Rajaustiedostoa %1 ei voitu poistaa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="331"/>
        <source>Could not copy default exclusion file from %1 to %2.</source>
        <translation>Rajaustiedoston kopiointi %1 kansioon %2 ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="614"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Tiedosto %1 on jo olemassa. Käytä toista tiedostonimeä tai poista olemassa oleva tiedosto.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="621"/>
        <source>Insufficient free space. Please select a different snapshot directory or free up space.</source>
        <translation>Tila ei riitä. Valitse vedokselle toinen hakemisto tai vapauta lisää tilaa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="631"/>
        <source>Snapshot will use the following settings:</source>
        <translation>Vedos käyttää seuraavia asetuksia:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="633"/>
        <source>- Snapshot directory:</source>
        <translation>- Vedosten kansio:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="634"/>
        <source>- Kernel to be used:</source>
        <translation>- Käytettävä kerneli:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="657"/>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>NVIDIA Detected</source>
        <translation>Nvidia havaittu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Tietokone käyttää Nvidia näytönohjainta. Käytätkö tuloksena olevaa ISO:a tässä tietokoneessa vai toisessa tietokoneessa, jossa on Nvidia?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="662"/>
        <source>NVIDIA Selected</source>
        <translation>Nvidia valittu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Huomaa: Jos käytät tuloksena olevaa ISO:a tietokoneessa, jossa ei ole nvidiaa, joudut todennäköisesti poistamaan &quot;xorg=nvidia&quot; käynnistysasetuksista.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="667"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Huomaa: Jos käytät tuloksena olevaa ISO:a tietokoneessa, jossa on nvidia, saatat joutua lisäämään &quot;xorg=nvidia&quot; käynnistysasetuksiin.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="702"/>
        <source>Could not replace the exclusion file with the updated default.</source>
        <translation>Rajaustiedostoa ei voitu korvata päivitetyllä oletuksella.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="721"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Nykyinen kerneli ei tue valittua pakkaamisen algoritmia, muokkaa asetustiedostoa ja valitse eri algoritmi.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="744"/>
        <source>Final chance</source>
        <translation>Viimeinen mahdollisuus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="746"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Työkalulla on nyt kaikki tarvittavat tiedot ISO-tiedoston luomiseen käynnissä olevasta järjestelmästä.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="747"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Viimeistely tulee kestämään kotvasen aikaa, riippuen asennetun järjestelmän koosta sekä tietokoneesi kapasiteetista.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="749"/>
        <source>OK to start?</source>
        <translation>Voidaanko aloittaa?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="753"/>
        <source>Shutdown computer when done.</source>
        <translation>Sammuta tietokone kun käsittely on valmis.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="786"/>
        <source>Output</source>
        <translation>Tuloste</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="802"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="809"/>
        <source>Edit Boot Menu</source>
        <translation>Muokkaa käynnistysvalikkoa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="810"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>Ohjelma pysäytetään, jotta voit muokata työhakemiston tiedostoja. Valitse Kyllä muokataksesi käynnistysvalikkoa tai valitse Ei ohittaaksesi tämän vaiheen ja jatka vedoksen luomista.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="846"/>
        <source>Revert the exclusion list to the default file? This will overwrite your current exclusions.</source>
        <translation>Palautetaanko oletus rajaustiedosto? Tämä korvaa nykyiset rajaukset.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="926"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="928"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="929"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Ohjelma jonka avulla voit luoda live-CD:n tällä hetkellä ajetusta järjestelmästä MX Linux:ille</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="931"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <source>%1 License</source>
        <translation>%1 lupa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="947"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="952"/>
        <source>Select Snapshot Directory</source>
        <translation>Valitse vedoksen kansio</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="960"/>
        <source>Insufficient free space in the selected directory. Please choose a different location.</source>
        <translation>Hakemistossa ei ole riittävästi tilaa. Valitse toinen sijainti.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="980"/>
        <source>Confirmation</source>
        <translation>Vahvistus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="980"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Oletko varma että haluat lopettaa sovelluksen?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>Ohjelma, jolla luodaan live-CD-levy käynnissä olevasta järjestelmästä</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="98"/>
        <source>Use CLI only</source>
        <translation>Käytä vain CLI</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>Number of CPU cores to be used.</source>
        <translation>Käytettävä prosessoriytimien määrä.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="103"/>
        <source>Output directory</source>
        <translation>Kohde hakemisto</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="104"/>
        <source>Output filename</source>
        <translation>Kohteen tiedostonimi</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="106"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Nimeä käytettäväksi toinen kernel kuin nyt oletuksena oleva kernel, käytä &quot;uname -r&quot; palauttamaa tietoa</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="108"/>
        <source>Or the full path: %1</source>
        <translation>tai täydellinen polku: %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="111"/>
        <source>Compression level options.</source>
        <translation>Pakkaustason valinta.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Käytä lainausmerkkejä: &quot;-Compression-level &lt;level&gt;&quot;, &quot;-Algoritm &lt;algorithm&gt;&quot; tai &quot;-Xhc&quot;, katso tarvittaessa mksquashfs man-ohjetta</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="116"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Tee tilannekuva kuukausittain, lisää ISO-nimeen kuluva &quot;kuukausi&quot;, ohita käytetyn tilan laskenta</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Tämä valinta asettaa palautustilit ja pakkauksen oletuksiin. Kohteita muuttavat argumentit ohitetaan</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="119"/>
        <source>Optionally specify a suffix to add to the month name (e.g., &apos;1&apos; for &apos;July.1&apos;)</source>
        <translation>Määritä halutessasi kuukauteen lisättävän päätteen (esim. &quot;1&quot; lisää päätteeksi &quot;Heinäkuu.1&quot;)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="120"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Älä laske valmistuvan ISO-tiedoston tarkistussummaa</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Ohita vapaan tilan laskeminen, tuloksena olevalle iso-levykuvalle on tilaa?</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="122"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Lisävalinta korjaamaan preempt_rt kernelin tarkistussumman laskemiseen liittyvän ongelman</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="123"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Käyttäjätilien tyhjennys (toisille jakamista varten)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="124"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Laske valmistuvan ISO-tiedoston tarkistussumma</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="126"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation>Kurista I/O-nopeutta annetulla prosentilla. Tätä voidaan käyttää vähentämään Mksquashfs I/O ja prosessorin varaamaa tehoa.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="129"/>
        <source>Work directory</source>
        <translation>Työkansio</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="131"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Jätä pois pääkansiot, vastaavat vaihtoehdot:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="133"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Käytä valintaa kerran kullekin kohteelle, jonka haluat sulkea pois </translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="136"/>
        <source>Compression format, valid choices: </source>
        <translation>Pakkausen formaatti, vastaavat vaihtoehdot:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="138"/>
        <source>Shutdown computer when done.</source>
        <translation>Sammuta tietokone kun käsittely on valmis.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="211"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="229"/>
        <source>version:</source>
        <translation>versio:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="223"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation>Sinun on suoritettava tämä ohjelma sudo:lla tai pkexec:llä.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="206"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="213"/>
        <location filename="../src/main.cpp" line="281"/>
        <location filename="../src/settings.cpp" line="527"/>
        <location filename="../src/settings.cpp" line="535"/>
        <location filename="../src/settings.cpp" line="1065"/>
        <location filename="../src/settings.cpp" line="1159"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="280"/>
        <location filename="../src/settings.cpp" line="534"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>Nykyinen kernel ei tue Squashfs-funktioita, joten ei voi jatkaa.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="113"/>
        <source>Failed to initialize configuration</source>
        <translation>Määrityksen alustaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="147"/>
        <source>Configuration validation failed</source>
        <translation>Määritysten vahvistus epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="152"/>
        <source>Exception during initialization: %1</source>
        <translation>Poikkeus alustuksen aikana: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="155"/>
        <source>Unknown exception during initialization</source>
        <translation>Tuntematon poikkeus alustuksen aikana</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="186"/>
        <source>Could not create work directory. </source>
        <translation>Työhakemiston luominen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="210"/>
        <source>Could not create temp directory:</source>
        <translation>Väliaikaista hakemistoa ei voitu luoda:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Please check that the parent directory exists and is writable:</source>
        <translation>Tarkista, että päähakemisto on olemassa ja että siihen voi kirjoittaa:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="229"/>
        <source>Compression format &apos;%1&apos; is not supported by the current kernel</source>
        <translation>Nykyinen kernel ei tue pakkausformaattia &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Invalid cores setting: %1. Must be between 1 and %2</source>
        <translation>Virheellinen ydinten asetus: %1. Arvon on oltava välillä 1–%2.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="241"/>
        <source>Invalid throttle setting: %1. Must be between 0 and 20</source>
        <translation>Virheellinen asetus: %1. Arvon on oltava välillä 0–20</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="247"/>
        <source>Snapshot directory cannot be empty</source>
        <translation>Vedoskansio ei voi olla tyhjä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="255"/>
        <source>Snapshot name cannot be empty</source>
        <translation>Vediksen nimi ei voi olla tyhjä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="261"/>
        <source>Snapshot name contains invalid characters: %1</source>
        <translation>Nimi sisältää virheellisiä merkkejä: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="267"/>
        <source>Kernel version cannot be empty</source>
        <translation>Kernel-versio ei voi olla tyhjä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="272"/>
        <source>Kernel file not found: /boot/vmlinuz-%1</source>
        <translation>Kernel-tiedostoa ei löytynyt: /boot/vmlinuz-%1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="278"/>
        <source>Kernel %1 doesn&apos;t support Squashfs</source>
        <translation>Kernel %1 ei tue Squashfs</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="309"/>
        <source>Exclusion file does not exist: %1</source>
        <translation>Poissulkemistiedostoa ei ole: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="318"/>
        <source>Unbalanced quotes in exclusion list</source>
        <translation>Väärät lainausmerkit poissulkemisluettelossa</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="343"/>
        <source>Insufficient free space: %1 KiB available, minimum %2 KiB required</source>
        <translation>Ei vapaata tilaa: %1 KiB käytettävissä, tarvitaan %2 KiB</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="350"/>
        <source>Insufficient free space in work directory: %1 KiB available, minimum %2 KiB required</source>
        <translation>Hakemistossa ei ole työtilaa: %1 KiB käytettävissä, tarvitaan %2 KiB</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="365"/>
        <source>Failed to determine number of CPU cores</source>
        <translation>Suorittimen ytimien määrän määrittäminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Configuration file does not exist: %1</source>
        <translation>Määritystiotiedostoa ei ole: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="372"/>
        <source>Using default settings</source>
        <translation>Oletusten käyttö</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="374"/>
        <source>Cannot read configuration file: %1</source>
        <translation>Määritystiedostoa ei voi lukea: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="375"/>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="385"/>
        <source>Required tool not found: %1</source>
        <translation>Vaadittua työkalua ei löytynyt: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="394"/>
        <source>Required directory not found: %1</source>
        <translation>Vaadittua hakemistoa ei löytynyt: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="413"/>
        <source>Initialization Error</source>
        <translation>Alustusvirhe</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="414"/>
        <source>Failed to initialize application settings:

%1</source>
        <translation>Sovelluksen asetusten alustus epäonnistui:

%1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="525"/>
        <source>Could not find a usable kernel</source>
        <translation>Ei löydetty sopivaa kerneliä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="526"/>
        <source>Searched for kernel files in /boot/ but none were found or accessible.</source>
        <translation>Etsittiin Kernel-tiedostoja /boot/ hakemistosta, mutta niitä ei löytynyt tai ne eivät olleet käytettävissä.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="547"/>
        <source>No users found in the system</source>
        <translation>Tietokoneesta ei löytynyt käyttäjiä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="550"/>
        <source>Failed to determine system information</source>
        <translation>Järjestelmätietoja ei voitu määrittää</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="644"/>
        <source>Used space on / (root): </source>
        <translation>Käytetty tila / (root): </translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="647"/>
        <source>estimated</source>
        <translation>arvioitu</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="656"/>
        <source>Used space on /home: </source>
        <translation>Käytetty tila /home -hakemistossa: </translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="712"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Vapaata tilaa %1, johon tilannekuva tallennetaan:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="716"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>Vapaata tilaa tulisi olla riittävästi pakatulle datalle kohteissa / ja /home 

            Tarvittaessa vapauta tilaa poistamalla aikaisempia
            vedoksia tai tallennetuja kopioita:
            Vedoksia %1 vie %2 levytilaa.
</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="730"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="731"/>
        <source>Documents</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="732"/>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="733"/>
        <source>Flatpaks</source>
        <translation>Flatpakit</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="734"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="735"/>
        <source>Networks</source>
        <translation>Verkot</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="736"/>
        <source>Pictures</source>
        <translation>Kuvat</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="738"/>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="887"/>
        <source>Error reading system configuration file: %1</source>
        <translation>Virhe järjestelmän määritystiedoston lukemisessa: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="895"/>
        <source>Error accessing user configuration</source>
        <translation>Virhe käyttäjämäärityksiä käytettäessä</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="947"/>
        <source>Could not copy exclusion file from %1 to %2</source>
        <translation>Rajaustiedoston kopiointi %1 kansioon %2 ei onnistunut.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="972"/>
        <source>Invalid stored cores setting (%1). Using detected CPU count: %2</source>
        <translation>Virheellinen asetus (%1) prosessoriydintä. Käytetään ytimine havaittua määrää: %2</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="1063"/>
        <location filename="../src/settings.cpp" line="1157"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Tiedosto %1 on jo olemassa. Käytä toista tiedostonimeä tai poista olemassa oleva tiedosto.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../src/work.cpp" line="144"/>
        <source>Cleaning...</source>
        <translation>Puhdistetaan...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="160"/>
        <location filename="../src/work.cpp" line="416"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="172"/>
        <source>Interrupted or failed to complete</source>
        <translation>Keskeytetty tai epäonnistunut</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="208"/>
        <location filename="../src/work.cpp" line="372"/>
        <location filename="../src/work.cpp" line="396"/>
        <location filename="../src/work.cpp" line="434"/>
        <location filename="../src/work.cpp" line="573"/>
        <location filename="../src/work.cpp" line="607"/>
        <location filename="../src/work.cpp" line="616"/>
        <location filename="../src/work.cpp" line="622"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="209"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Levyllä ei ole tarpeeksi vapaata tilaa, tarvitset vähintään %1</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="212"/>
        <source>You have %1 free space on %2</source>
        <translation>Sinulla on %1 vapaata tilaa kohteessa %2</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="215"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Jos olet varma, että sinulla on tarpeeksi vapaata tilaa, suorita ohjelma uudelleen -o/--override-size vailinnalla</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="300"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Jäljennetään new-iso tiedostojärjestelmää...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="312"/>
        <source>Could not create temp directory. </source>
        <translation>Tilapäiskansiota ei voitu luoda.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="369"/>
        <source>Squashing filesystem...</source>
        <translation>Puristetaan tiedostojärjestelmää...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="373"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation>Ei voitu luoda linuxfs-tiedostoa, tarkista /var/log/%1.log</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="393"/>
        <source>Creating CD/DVD image file...</source>
        <translation>CD/DVD-levykuvatiedostoa luodaan...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="397"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>ISO-tiedostoa ei voitu luoda, tarkista onko kohdeosiolla tarpeeksi levytilaa.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="403"/>
        <source>Making hybrid iso</source>
        <translation>Tuotetaan risteytetty ISO</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="421"/>
        <source>Success</source>
        <translation>Onnistui</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="422"/>
        <source>MX Snapshot completed successfully!</source>
        <translation>MX Snapshot valmistui onnistuneesti!</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="423"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>Snapshot valmistuminen kesti %1.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="424"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Kiitos kun käytit MX Snapshot työkalua. Suorita MX Live USB Maker seuraavaksi!</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="431"/>
        <source>Installing </source>
        <translation>Asennetaan</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="434"/>
        <source>Could not install </source>
        <translation>Ei voitu asentaa</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="444"/>
        <source>Calculating checksum...</source>
        <translation>Lasketaan tarkistussummaa...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="483"/>
        <source>Building new initrd...</source>
        <translation>Rakennetaan uutta initrd:tä...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="574"/>
        <source>Could not create working directory. </source>
        <translation>Työkansiota ei voitu luoda.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="608"/>
        <source>Could not prepare a safe bind-root overlay. Snapshot cannot continue.</source>
        <translation>Sidonta root-tasolle epäonnistui. Vedoksen luontia ei voi jatkaa.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="617"/>
        <location filename="../src/work.cpp" line="623"/>
        <source>Could not prepare the snapshot bind-root environment.</source>
        <translation>Vedoksen sidonta ja valmistelu root-ympäristölle epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="742"/>
        <source>Calculating total size of excluded files...</source>
        <translation>Lasketaan poissuljettujen tiedostojen kokoa...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="752"/>
        <source>Calculating size of root...</source>
        <translation>Lasketaan root kokoa...</translation>
    </message>
</context>
</TS>